#
# spec file for package skopeo
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# nodebuginfo


%define project        github.com/containers/skopeo

%if 0%{?is_opensuse} && 0%{?suse_version} >= 1500
# Build with libostree-devel for openSUSE Tumbleweed and Leap 15
%define with_libostree 1
%endif
Name:           skopeo
Version:        0.1.41
Release:        lp151.2.6.1
Summary:        Container image repository tool
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/containers/skopeo
Source:         %{name}-%{version}.tar.xz
Source1:        skopeo.rpmlintrc
Requires:       libcontainers-common
BuildRequires:  device-mapper-devel >= 1.2.68
BuildRequires:  glib2-devel
BuildRequires:  golang(API) = 1.12
BuildRequires:  go-go-md2man
BuildRequires:  libbtrfs-devel >= 3.8
BuildRequires:  libcontainers-common
BuildRequires:  libgpgme-devel
ExcludeArch:    s390
%if 0%{?with_libostree}
BuildRequires:  libostree-devel
%endif

%description
skopeo is a command line utility for various operations on container images and
image repositories. skopeo is able to inspect a repository on a Docker registry
and fetch images layers. skopeo can copy container images between various
storage mechanisms.

%prep
%setup -q

%build
mkdir -p .gopath/src/github.com/containers
ln -s $PWD .gopath/src/%{project}
export GOPATH=$PWD/.gopath

export BUILDTAGS="exclude_graphdriver_aufs"

%if 0%{?suse_version} <= 1320
	BUILDTAGS+=" libdm_no_deferred_remove"
%endif

# Starting from https://github.com/containers/image/pull/587, ostree is disabled
# by default.
%if 0%{?with_libostree}
	BUILDTAGS+=" containers_image_ostree"
%endif

# Build.
GO111MODULE=on go build -mod=vendor "-buildmode=pie" -ldflags "-X main.gitCommit=" -gcflags "" -tags "$BUILDTAGS" -o skopeo %{project}/cmd/skopeo
make %{?_smp_mflags} docs

%install
# Install the binary.
make INSTALLDIR="%{buildroot}/%{_bindir}" install-binary

# Install the docs.
make MANINSTALLDIR="%{buildroot}/%{_mandir}" install-docs

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man1/skopeo*.1*

%changelog
* Wed Mar  4 2020 Ralf Haferkamp <rhafer@suse.com>
- Removed patches that were merged upstream:
  - 0002-Add-set-of-image-options-used-only-for-docker-transp.patch
  - bsc1115165-0001-Introduce-the-sync-command.patch
  - CVE-2019-10214.patch
- Update to skopeo v0.1.41 (bsc#1165715):
  - Bump github.com/containers/image/v5 from 5.2.0 to 5.2.1
  - Bump gopkg.in/yaml.v2 from 2.2.7 to 2.2.8
  - Bump github.com/containers/common from 0.0.7 to 0.1.4
  - Remove the reference to openshift/api
  - vendor github.com/containers/image/v5@v5.2.0
  - Manually update buildah to v1.13.1
  - add specific authfile options to copy (and sync) command.
  - Bump github.com/containers/buildah from 1.11.6 to 1.12.0
  - Add context to --encryption-key / --decryption-key processing
    failures
  - Bump github.com/containers/storage from 1.15.2 to 1.15.3
  - Bump github.com/containers/buildah from 1.11.5 to 1.11.6
  - remove direct reference on c/image/storage
  - Makefile: set GOBIN
  - Bump gopkg.in/yaml.v2 from 2.2.2 to 2.2.7
  - Bump github.com/containers/storage from 1.15.1 to 1.15.2
  - Introduce the sync command
  - openshift cluster: remove .docker directory on teardown
  - Bump github.com/containers/storage from 1.14.0 to 1.15.1
  - document installation via apk on alpine
  - Fix typos in doc for image encryption
  - Image encryption/decryption support in skopeo
  - make vendor-in-container
  - Bump github.com/containers/buildah from 1.11.4 to 1.11.5
  - Travis: use go v1.13
  - Use a Windows Nano Server image instead of Server Core for
    multi-arch testing
  - Increase test timeout to 15 minutes
  - Run the test-system container without --net=host
  - Mount /run/systemd/journal/socket into test-system containers
  - Don't unnecessarily filter out vendor from (go list ./...)
    output
  - Use -mod=vendor in (go {list,test,vet})
  - Bump github.com/containers/buildah from 1.8.4 to 1.11.4
  - Bump github.com/urfave/cli from 1.20.0 to 1.22.1
  - skopeo: drop support for ostree
  - Don't critically fail on a 403 when listing tags
  - Revert "Temporarily work around auth.json location confusion"
  - Remove references to atomic
  - Remove references to storage.conf
  - Dockerfile: use golang-github-cpuguy83-go-md2man
  - bump version to v0.1.41-dev
  - systemtest: inspect container image different from current
    platform arch
- Changes in v0.1.40:
  - vendor containers/image v5.0.0
  - copy: add a --all/-a flag
  - System tests: various fixes
  - Temporarily work around auth.json location confusion
  - systemtest: copy: docker->storage->oci-archive
  - systemtest/010-inspect.bats: require only PATH
  - systemtest: add simple env test in inspect.bats
  - bash completion: add comments to keep scattered options in sync
  - bash completion: use read -r instead of disabling SC2207
  - bash completion: support --opt arg completion
  - bash-completion: use replacement instead of sed
  - bash completion: disable shellcheck SC2207
  - bash completion: double-quote to avoid re-splitting
  - bash completions: use bash replacement instead of sed
  - bash completion: remove unused variable
  - bash-completions: split decl and assignment to avoid masking
    retvals
  - bash completion: double-quote fixes
  - bash completion: hard-set PROG=skopeo
  - bash completion: remove unused variable
  - bash completion: use `||` instead of `-o`
  - bash completion: rm eval on assigned variable
  - copy: add --dest-compress-format and --dest-compress-level
  - flag: add optionalIntValue
  - Makefile: use go proxy
  - inspect --raw: skip the NewImage() step
  - update OCI image-spec to
    775207bd45b6cb8153ce218cc59351799217451f
  - inspect.go: inspect env variables
  - ostree: use both image and & storage buildtags
* Mon Sep  2 2019 Sascha Grunert <sgrunert@suse.com>
- Add patch for CVE-2019-10214. bsc#1144065
  + CVE-2019-10214.patch
* Wed Aug  7 2019 Marco Vedovati <mvedovati@suse.com>
- Update to skopeo v0.1.39 (bsc#1159530):
  - inspect: add a --config flag
  - Add --no-creds flag to skopeo inspect
  - Add --quiet option to skopeo copy
  - New progress bars
  - Parallel Pulls and Pushes for major speed improvements
  - containers/image moved to a new progress-bar library to fix various
    issues related to overlapping bars and redundant entries.
  - enforce blocking of registries
  - Allow storage-multiple-manifests
  - When copying images and the output is not a tty (e.g., when piping to a
    file) print single lines instead of using progress bars. This avoids
    long and hard to parse output
  - man pages: add --dest-oci-accept-uncompressed-layers
  - completions:
  - Introduce transports completions
  - Fix bash completions when a option requires a argument
  - Use only spaces in indent
  - Fix completions with a global option
  - add --dest-oci-accept-uncompressed-layers
- Update bsc1115165-0001-Introduce-the-sync-command.patch and add
  0002-Add-set-of-image-options-used-only-for-docker-transp.patch
  required by the updated sync patch.
* Tue Nov 27 2018 Marco Vedovati <mvedovati@suse.com>
- Disable ostree repository types for SLE, as this feature requires libostree
  that is not yet available in the Server Application module where skopeo is
  located.
* Thu Nov 15 2018 Marco Vedovati <mvedovati@suse.com>
- Update to skopeo v0.1.32:
  * Add command time out support
  * Updates to vendored libraries
- Add a patch that implements the `skopeo sync` command, generated from the
  upstream PR: https://github.com/containers/skopeo/pull/524
  Fix bsc#1115165
  + bsc1115165-0001-Introduce-the-sync-command.patch
- Update project location from 'projectatomic' to 'containers'
* Mon Jul 30 2018 vrothberg@suse.com
- Update to skopeo v0.1.31:
  * Fix compilation on i586
* Wed Jun 13 2018 dcassany@suse.com
- Make use of %%license macro
* Tue May 22 2018 vrothberg@suse.com
- Update to skopeo v0.1.30:
  * skopeo-copy: docker-archive: multitag support
  * Updates to vendored libraries
* Tue Mar 27 2018 vrothberg@suse.com
- Run spec-cleaner on skopeo.spec
- Enable ostree support on Tumbleweed, Leap 15 and SLE 15
- Enable support for containers/storage, which is especially useful to further
  support Podman and cri-o.
- Update to skopeo v0.1.28:
  * vendor: bump containers/image and containers/image
  * Cleanup skopeo man page and README.md
  * Use credentials from authfile for skopeo commands
  * Update to a newer containers/storage master
  * Add global --override-arch and --override-os options
* Mon Feb 12 2018 vrothberg@suse.com
- Add requirement on libcontainers-common, which now provides the
  /etc/containers/policy.json config.
* Thu Feb  1 2018 ro@suse.de
- do not build on s390, only on s390x (no go on s390)
* Mon Nov 20 2017 asarai@suse.com
- Update to skopeo v0.1.26. This includes a fix for CVE-2017-14992.
- Disable containers/storage integration by default (through
  containers_image_storage_stub), as it is very dodgy and not widely used.
* Sat Oct 21 2017 asarai@suse.com
- Update to skopeo v0.1.24. Upstream changelog:
  * Improvements to macOS builds: A make binary-local should work without extra options.
  * make install on macOS now installs to /usr/local
  * The destination in docker-archive: now can be a pipe.
  * When building with containers_image_openpgp, signatures with PGP v3 signature packets are accepted.
  * Unreadable /etc/docker/certs.d now only logs a warning instead of aborting the operation.
  * oci-layout: naming semantics changes:
  * A full range of org.opencontainers.image.ref.name values is now accepted
  * A name must be specified for oci-layout: destinations (it does not default to latest any more).
  * For oci-layout: sources, a name is now optional if the image index contains exactly one image (instead of using the image with the latest name).
  * Policy configuration identities of oci-layout: images now consist only of the directory name, to avoid the ambiguity created by the unspecified annotation values above.
  * ~/.docker/config.json credential helpers (configured in credHelpers) are now supported.
  * Annotations are now preserved when copying and compressing OCI images.
  * New transport oci-archive:, works exactly like oci-layout:, but works on tarballs instead of extracted directories.
  * When copying images, skopeo always asks for the same image schema, and optionally converts the image itself to make it acceptable to the destination, instead of asking for a schema dependent on the destinations’ capabilities (relying on the source to convert the image).
  * Improved installation instructions.
  * ostree: image names can now contain colons (e.g. port specifications)
  * skopeo now does not declare support for manifest lists, so that the source registry provides a single image. This allows skopeo copy to copy various images recently published to Docker Hub. (More complete support for manifest lists will come in the future.)
  * The containers-storage: backend has been updated, incl. support for the override_kernel_checks option.
  * Improved the output of progress bars in skopeo copy.
  * Fixed fetching blobs with external URLs in images served by docker/distribution registries.
  * OCI images now support reading blobs with external URLs, ands storing information about such blobs without copying the contents.
  * Writing ostree: images creates a docker.digest annotation.
  * docker/distribution registry credentials are now read from $XDG_RUNTIME_DIR/containers/auth.json before trying ~/.docker/config.json and ~/.dockercfg.
  * skopeo inspect no longer crashes on images where the config blob does not contain a container configuration.
* Wed Sep  6 2017 asarai@suse.com
- Add -buildmode=pie to fix bugs building on ppc64le.
* Sat Jul 22 2017 asarai@suse.com
- Update to skopeo v0.1.23. This supports OCI v1, as well as a variety of new
  transports such as docker-archive and ostree.
- Disable ostree builds by default with %%bcond_with, as only Tumbleweed has
  libostree and we need skopeo for KIWI.
* Fri Apr 14 2017 asarai@suse.com
- Update to skopeo 0.1.19, which supports 1.0.0-rc4 of the image-spec as well
  as all of our patches have been merged upstream.
  - 0001-docker-split-tarfile-code-from-docker-daemon-code.patch
  - 0002-docker-add-docker-archive-transport.patch
  - 0003-squashme-docker-tarfile-make-tagging-work-properly.patch
  - 0004-squashme-docker-archive-handle-mtrmac-s-comments.patch
  - 0005-squashme-docker-archive-correctly-handle-tagging.patch
  - 0006-copy-move-compression-to-separate-pkg.patch
  - 0007-docker-daemon-decompress-blobs-transparently-in-GetB.patch
  - oci-remove-MIME-type-autodetection.patch
* Wed Feb 15 2017 asarai@suse.com
- Add further patches to handle OCI <-> Docker translation properly. This is
  necessary for KIWI integration. https://github.com/containers/image/pull/237
  + oci-remove-MIME-type-autodetection.patch
* Tue Feb  7 2017 asarai@suse.com
- Add buildtags to handle the Docker-like buildtags such as
  libdm_no_deferred_remove and exclude_graphdriver_aufs.
* Tue Feb  7 2017 asarai@suse.com
- Add patches for docker-archive transport.
  + 0001-docker-split-tarfile-code-from-docker-daemon-code.patch
  + 0002-docker-add-docker-archive-transport.patch
  + 0003-squashme-docker-tarfile-make-tagging-work-properly.patch
  + 0004-squashme-docker-archive-handle-mtrmac-s-comments.patch
  + 0005-squashme-docker-archive-correctly-handle-tagging.patch
  + 0006-copy-move-compression-to-separate-pkg.patch
  + 0007-docker-daemon-decompress-blobs-transparently-in-GetB.patch
* Tue Feb  7 2017 asarai@suse.com
- Bump to skopeo v0.1.18. Many updates to containers/image, and fixes to the
  Docker v2s2 schema conversion.
* Tue Dec 13 2016 asarai@suse.com
- Bump to skopeo v0.1.17. This version includes many, many fixes to OCI image
  handling as well as adding features such as the docker-daemon: transport.
  There are also several UX fixes to how passwords are managed.
* Thu Dec  8 2016 asarai@suse.com
- Bump to v0.1.16+r54 (a865c07818ed914e2602205be6e9d67debc1d660). This is
  necessary so that we don't need to do major backporting of containers/image.
  skopeo intends to bump themselves to v0.1.17 in the coming week so this is
  just a temporary measure.
- Removed patches no longer needed.
  - oci-fix-mediatypes.patch
* Fri Nov 11 2016 asarai@suse.com
- Backport OCI mediatype fixes. https://github.com/projectatomic/skopeo/pull/221
  + oci-fix-mediatypes.patch
* Fri Nov 11 2016 asarai@suse.com
- Initial import of skopeo v0.1.16.
